@@ -198,7 +198,14 @@ fgam <- function(formula,fitter=NA,tensortype=c('te','t2'),...){
   newfrml <- formula(paste(c(newfrml, newtrmstrings), collapse = "+"))
   environment(newfrml) <- newfrmlenv
   fgamdata <- list2df(as.list(newfrmlenv))
-  datameans <- sapply(as.list(newfrmlenv), mean)
+  datameans <- sapply(as.list(newfrmlenv), function(x){
+    if (is.numeric(x) | is.logical(x)) {
+      mean(x)
+    }else if (is.factor(x)){
+      names(which.max(table(x)))
+    }else
+        NA
+  })
   newcall <- expand.call(fgam, call)
   newcall$fitter <- type <- newcall$bs.int <- newcall$bs.yindex <- newcall$fitter <- NULL
   newcall$formula <- newfrml
